translate.storage.placeables.xliff

Package translate :: Package storage :: Package placeables :: Module xliff |
[hide private]
[frames] | no frames]

# Module xliff

source code

Contains XLIFF-specific placeables.

Classes | [hide private]
| Bpt
| Ept
| Ph
| It
| G
| Bx
| Ex
| X
| Sub
| UnknownXML Placeable for unrecognized or umimplemented XML nodes.

Functions | [hide private]
to_xliff_placeables(tree) | source code

Variables | [hide private]
| parsers = `[]`
| __package__ = ``'``translate.storage.placeables``'``

Imports: base, StringElem